@@ -31,6 +31,7 @@ enum hlr_vty_node {
 	HLR_NODE = _LAST_OSMOVTY_NODE + 1,
 	GSUP_NODE,
 	EUSE_NODE,
+	SMSC_NODE,
 	MSLOOKUP_NODE,
 	MSLOOKUP_SERVER_NODE,
 	MSLOOKUP_SERVER_MSC_NODE,
@@ -47,7 +48,6 @@ enum hlr_vty_node {
 #define A38_COMP128_KEY_LEN	16
 #define MILENAGE_KEY_LEN	16
 
-int hlr_vty_is_config_node(struct vty *vty, int node);
 int hlr_vty_go_parent(struct vty *vty);
 void hlr_vty_init(void *hlr_ctx);
 void dgsm_vty_init(void);
