@@ -26,6 +26,7 @@
 #include <osmocom/gsupclient/gsup_client.h>
 
 #include <osmocom/abis/ipa.h>
+#include <osmocom/gsm/ipa.h>
 #include <osmocom/gsm/oap_client.h>
 #include <osmocom/gsm/protocol/ipaccess.h>
 #include <osmocom/core/msgb.h>
@@ -44,7 +45,7 @@ static void gsup_client_send_ping(struct osmo_gsup_client *gsupc)
 
 	msg->l2h = msgb_put(msg, 1);
 	msg->l2h[0] = IPAC_MSGT_PING;
-	ipa_msg_push_header(msg, IPAC_PROTO_IPACCESS);
+	ipa_prepend_header(msg, IPAC_PROTO_IPACCESS);
 	ipa_client_conn_send(gsupc->link, msg);
 }
 
@@ -114,7 +115,7 @@ static void client_send(struct osmo_gsup_client *gsupc, int proto_ext,
 			struct msgb *msg_tx)
 {
 	ipa_prepend_header_ext(msg_tx, proto_ext);
-	ipa_msg_push_header(msg_tx, IPAC_PROTO_OSMO);
+	ipa_prepend_header(msg_tx, IPAC_PROTO_OSMO);
 	ipa_client_conn_send(gsupc->link, msg_tx);
 	/* msg_tx is now queued and will be freed. */
 }
@@ -306,7 +307,7 @@ struct osmo_gsup_client *osmo_gsup_client_create3(void *talloc_ctx, struct osmo_
 
 	OSMO_ASSERT(config->ipa_dev->unit_name);
 
-	gsupc = talloc_zero(talloc_ctx, struct osmo_gsup_client);
+	gsupc = talloc(talloc_ctx, struct osmo_gsup_client);
 	OSMO_ASSERT(gsupc);
 	*gsupc = (struct osmo_gsup_client){
 		.unit_name = (const char *)config->ipa_dev->unit_name, /* API backwards compat */
@@ -449,3 +450,36 @@ struct msgb *osmo_gsup_client_msgb_alloc(void)
 {
 	return msgb_alloc_headroom(4000, 64, __func__);
 }
+
+void *osmo_gsup_client_get_data(const struct osmo_gsup_client *gsupc)
+{
+	return gsupc->data;
+}
+
+void osmo_gsup_client_set_data(struct osmo_gsup_client *gsupc, void *data)
+{
+	gsupc->data = data;
+}
+
+const char *osmo_gsup_client_get_rem_addr(const struct osmo_gsup_client *gsupc)
+{
+	if (!gsupc->link)
+		return NULL;
+	return gsupc->link->addr;
+}
+uint16_t osmo_gsup_client_get_rem_port(const struct osmo_gsup_client *gsupc)
+{
+	if (!gsupc->link)
+		return 0;
+	return gsupc->link->port;
+}
+
+bool osmo_gsup_client_is_connected(const struct osmo_gsup_client *gsupc)
+{
+	return gsupc->is_connected;
+}
+
+const struct ipaccess_unit *osmo_gsup_client_get_ipaccess_unit(const struct osmo_gsup_client *gsupc)
+{
+	return gsupc->ipa_dev;
+}
